==> e2fsprogs-1.41.5-i486-1sys.tgz: install/doinst.sh <==
#!/bin/sh
config() {
  NEW="$1"
  OLD="$(dirname $NEW)/$(basename $NEW .new)"
  # If there's no config file by that name, mv it over:
  if [ ! -r $OLD ]; then
    mv $NEW $OLD
  elif [ "$(cat $OLD | md5sum)" = "$(cat $NEW | md5sum)" ]; then # toss the redundant copy
    rm $NEW
  fi
  # Otherwise, we leave the .new copy for the admin to consider...
}
#config /usr/etc/mke2fs.conf   # .new
if [ -x /usr/bin/install-info ]; then
  install-info --info-dir=/usr/info /usr/info/libext2fs.info.gz 2> /dev/null
fi

cp -f /etc/mke2fs.conf /etc/mke2fs.conf.old 
rm /etc/mke2fs.conf
ln -s /usr/etc/mke2fs.conf   /etc/mke2fs.conf


( cd /usr/sbin ; rm -rf mkfs.ext2 )
( cd /usr/sbin ; ln -sf mke2fs mkfs.ext2 )
( cd /usr/sbin ; rm -rf mkfs.ext3 )
( cd /usr/sbin ; ln -sf mke2fs mkfs.ext3 )
( cd /usr/sbin ; rm -rf mkfs.ext4 )
( cd /usr/sbin ; ln -sf mke2fs mkfs.ext4 )
( cd /usr/sbin ; rm -rf mkfs.ext4dev )
( cd /usr/sbin ; ln -sf mke2fs mkfs.ext4dev )
( cd /usr/sbin ; rm -rf mkfs.ext5 )
( cd /usr/sbin ; ln -sf mke2fs mkfs.ext5 )

( cd /usr/sbin ; rm -rf fsck.ext3 )
( cd /usr/sbin ; ln -sf fsck.ext2 fsck.ext3 )
( cd /usr/sbin ; rm -rf fsck.ext4 )
( cd /usr/sbin ; ln -sf fsck.ext2 fsck.ext4 )
( cd /usr/sbin ; rm -rf fsck.ext4dev )
( cd /usr/sbin ; ln -sf fsck.ext2 fsck.ext4dev )
( cd /usr/sbin ; rm -rf fsck.ext5 )
( cd /usr/sbin ; ln -sf fsck.ext2 fsck.ext5 )


( cd /usr/sbin ; rm -rf findfs )
( cd /usr/sbin ; ln -sf tune2fs findfs )
( cd /usr/sbin ; rm -rf e2label )
( cd /usr/sbin ; ln -sf tune2fs e2label )

#


#
( cd usr/lib ; rm -rf libblkid.so )
( cd usr/lib ; ln -sf libblkid.so.1 libblkid.so )
( cd usr/lib ; rm -rf libcom_err.so )
( cd usr/lib ; ln -sf libcom_err.so.2 libcom_err.so )
( cd usr/lib ; rm -rf libcom_err.so.2 )
( cd usr/lib ; ln -sf libcom_err.so.2.1 libcom_err.so.2 )
( cd usr/lib ; rm -rf libss.so.2 )
( cd usr/lib ; ln -sf libss.so.2.0 libss.so.2 )
( cd usr/lib ; rm -rf libuuid.so )
( cd usr/lib ; ln -sf libuuid.so.1 libuuid.so )
( cd usr/lib ; rm -rf libss.so )
( cd usr/lib ; ln -sf libss.so.2 libss.so )
( cd usr/lib ; rm -rf libe2p.so )
( cd usr/lib ; ln -sf libe2p.so.2 libe2p.so )
( cd usr/lib ; rm -rf libext2fs.so.2 )
( cd usr/lib ; ln -sf libext2fs.so.2.4 libext2fs.so.2 )
( cd usr/lib ; rm -rf libext2fs.so )
( cd usr/lib ; ln -sf libext2fs.so.2 libext2fs.so )
( cd usr/lib ; rm -rf libuuid.so.1 )
( cd usr/lib ; ln -sf libuuid.so.1.2 libuuid.so.1 )
( cd usr/lib ; rm -rf libe2p.so.2 )
( cd usr/lib ; ln -sf libe2p.so.2.3 libe2p.so.2 )
( cd usr/lib ; rm -rf libblkid.so.1 )
( cd usr/lib ; ln -sf libblkid.so.1.0 libblkid.so.1 )

==> e2fsprogs-1.41.9-i486-1sys.tgz: install/doinst.sh <==
#!/bin/sh
config() {
  NEW="$1"
  OLD="$(dirname $NEW)/$(basename $NEW .new)"
  # If there's no config file by that name, mv it over:
  if [ ! -r $OLD ]; then
    mv $NEW $OLD
  elif [ "$(cat $OLD | md5sum)" = "$(cat $NEW | md5sum)" ]; then # toss the redundant copy
    rm $NEW
  fi
  # Otherwise, we leave the .new copy for the admin to consider...
}

cp -f /etc/mke2fs.conf /etc/mke2fs.conf.old 
config /etc/mke2fs.conf.new


rm /usr/etc/mke2fs.conf
ln -s /etc/mke2fs.conf   /usr/etc/mke2fs.conf


if [ -x /usr/bin/install-info ]; then
  install-info --info-dir=/usr/info /usr/info/libext2fs.info.gz 2> /dev/null
fi

( cd /usr/sbin ; rm -rf mkfs.ext2 )
( cd /usr/sbin ; ln -sf mke2fs mkfs.ext2 )
( cd /usr/sbin ; rm -rf mkfs.ext3 )
( cd /usr/sbin ; ln -sf mke2fs mkfs.ext3 )
( cd /usr/sbin ; rm -rf mkfs.ext4 )
( cd /usr/sbin ; ln -sf mke2fs mkfs.ext4 )
( cd /usr/sbin ; rm -rf mkfs.ext4dev )
( cd /usr/sbin ; ln -sf mke2fs mkfs.ext4dev )
( cd /usr/sbin ; rm -rf mkfs.ext5 )
( cd /usr/sbin ; ln -sf mke2fs mkfs.ext5 )

( cd /sbin ; rm -rf fsck )
( cd /sbin ; ln -sf /usr/sbin/fsck fsck )

( cd /usr/sbin ; rm -rf fsck.ext3 )
( cd /usr/sbin ; ln -sf fsck.ext2 fsck.ext3 )
( cd /usr/sbin ; rm -rf fsck.ext4 )
( cd /usr/sbin ; ln -sf fsck.ext2 fsck.ext4 )
( cd /usr/sbin ; rm -rf fsck.ext4dev )
( cd /usr/sbin ; ln -sf fsck.ext2 fsck.ext4dev )
( cd /usr/sbin ; rm -rf fsck.ext5 )
( cd /usr/sbin ; ln -sf fsck.ext2 fsck.ext5 )


( cd /usr/sbin ; rm -rf findfs )
( cd /usr/sbin ; ln -sf tune2fs findfs )
( cd /usr/sbin ; rm -rf e2label )
( cd /usr/sbin ; ln -sf tune2fs e2label )

#


#
( cd usr/lib ; rm -rf libblkid.so )
( cd usr/lib ; ln -sf libblkid.so.1 libblkid.so )
( cd usr/lib ; rm -rf libcom_err.so )
( cd usr/lib ; ln -sf libcom_err.so.2 libcom_err.so )
( cd usr/lib ; rm -rf libcom_err.so.2 )
( cd usr/lib ; ln -sf libcom_err.so.2.1 libcom_err.so.2 )
( cd usr/lib ; rm -rf libss.so.2 )
( cd usr/lib ; ln -sf libss.so.2.0 libss.so.2 )
( cd usr/lib ; rm -rf libuuid.so )
( cd usr/lib ; ln -sf libuuid.so.1 libuuid.so )
( cd usr/lib ; rm -rf libss.so )
( cd usr/lib ; ln -sf libss.so.2 libss.so )
( cd usr/lib ; rm -rf libe2p.so )
( cd usr/lib ; ln -sf libe2p.so.2 libe2p.so )
( cd usr/lib ; rm -rf libext2fs.so.2 )
( cd usr/lib ; ln -sf libext2fs.so.2.4 libext2fs.so.2 )
( cd usr/lib ; rm -rf libext2fs.so )
( cd usr/lib ; ln -sf libext2fs.so.2 libext2fs.so )
( cd usr/lib ; rm -rf libuuid.so.1 )
( cd usr/lib ; ln -sf libuuid.so.1.2 libuuid.so.1 )
( cd usr/lib ; rm -rf libe2p.so.2 )
( cd usr/lib ; ln -sf libe2p.so.2.3 libe2p.so.2 )
( cd usr/lib ; rm -rf libblkid.so.1 )
( cd usr/lib ; ln -sf libblkid.so.1.0 libblkid.so.1 )
#
